@@ -35,7 +35,7 @@ function (y, pool=TRUE, cl=list(fnscale=-1), meth="L-BFGS-B", hess=FALSE)
     }
 
   # add more information to results (p0, SE, K, n, IC scores)
-  if (hess)		w$se<- sqrt(-1/diag(w$hessian))
+  if (hess)		w$se<- sqrt(diag(-1*solve(w$hessian)))
   w$p0<- p0
   w$K<- 2
   w$n<- length(y$mm)-1
